#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_DIVS_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_DIVS_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/divs.hpp>

#endif
